Function split
fn split<'s, T>(s: &'s T, boundaries: &[Boundary]) -> Vec<&'s str>
where
T: AsRef<str>
Split an identifier into a list of words using the list of boundaries.
This is used internally for splitting an identifier before mutating by a pattern and joining again with a delimiter.
use ;
assert_eq!